Format function definition (sarpy.io.general.format_function)
=============================================================

.. automodule:: sarpy.io.general.format_function
    :members:
    :show-inheritance:
    :inherited-members:
